==> ejc-supbid-impl-3.0.1-20211214.095814-51-sources.jar: com/ejianc/business/supbid/util/SendMsgUtils.java <==
package com.ejianc.business.supbid.util;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.message.vo.PushMsgParameter;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;

/**
 * 消息发送工具类
 */
public class SendMsgUtils {
    /** 日志 */
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    /** 消息类型 msgType:notice */
    private static final String MSG_TYPE_NOTICE = "notice";

    /**
     * 发送系统消息（只发送系统消息，消息类型默认为 notice）
     *
     * @param userList       消息接收用户
     * @param subject        消息标题
     * @param content        消息内容
     * @param pushMessageApi 发送消息API
     */
    public void sendSysMsg(List<String> userList, String subject, String content, IPushMessageApi pushMessageApi) {
        List<String> messageTypeList = new ArrayList<>();
        //系统消息
        messageTypeList.add("sys");
        this.sendMsg(messageTypeList, userList, MSG_TYPE_NOTICE, subject, content, null, null, null, pushMessageApi);
    }

    /**
     * 发送消息
     *
     * @param messageTypeList 消息发送类型
     * @param userList        消息接收用户
     * @param msgType         消息类型
     * @param subject         消息标题
     * @param content         消息内容
     * @param cgddAgentid     cgddAgentid（微信消息使用）
     * @param cgddSecret      cgddSecret （微信消息使用）
     * @param url             微信消息URL（微信消息使用）
     * @param pushMessageApi  发送消息API
     */
    public void sendMsg(List<String> messageTypeList, List<String> userList, String msgType, String subject,
                        String content, String cgddAgentid, String cgddSecret, String url,
                        IPushMessageApi pushMessageApi) {
        logger.info("发送消息开始！===========");
        PushMsgParameter parameter = new PushMsgParameter();
        List<String> channel = new ArrayList<>();
        if (messageTypeList.contains("sys")) {
            // 系统消息
            channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
        }
        if (messageTypeList.contains("smsg")) {
            // 短信消息
//             channel.add(PushMsgParameter.CHANNEL_TYPE_NOTE);
        }
        if (messageTypeList.contains("weChat")) {
            // 系统消息
            channel.add(PushMsgParameter.CHANNEL_TYPE_WEXINEE);
        }
        String[] receivers = userList.toArray(new String[0]);
        parameter.setReceivers(receivers);// 收信人
        parameter.setChannel(channel.toArray(new String[0]));// 消息类型
        parameter.setMsgType(msgType);
        parameter.setSubject(subject);// 标题
        parameter.setContent(content);// 内容
        parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
        parameter.setSendUserId(InvocationInfoProxy.getUserid());

        if (messageTypeList.contains("weChat")) {
            JSONObject weixineeParams = new JSONObject();
            weixineeParams.put("agentid", cgddAgentid);
            weixineeParams.put("secret", cgddSecret);
            weixineeParams.put("msgtype", "textcard");
            weixineeParams.put("title", "消息提醒");
            weixineeParams.put("description", subject);
            weixineeParams.put("url", url);
            weixineeParams.put("btntxt", "点击查看");
            parameter.setWeixineeParams(weixineeParams);
        }
        try {
            logger.info("消息发送参数---------------->{}", parameter.toString());
            CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
            if (result.isSuccess()) {
                logger.info("消息发送成功---------------->" + result.getMsg());
            }
            else {
                logger.error("消息发送失败---------------->" + result.getMsg());
            }
        }
        catch (Exception e) {
            logger.error("调用消息中心RPC服务异常--------------" + e);
        }
    }

}

==> ejc-supbid-impl-3.0.1-20211215.031634-57-sources.jar: com/ejianc/business/supbid/util/SendMsgUtils.java <==
package com.ejianc.business.supbid.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.message.vo.PushMsgParameter;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;

/**
 * 消息发送工具类
 */
public class SendMsgUtils {
    /** 日志 */
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    /** 消息类型 msgType:notice */
    private static final String MSG_TYPE_NOTICE = "notice";

    /**
     * 发送系统消息（只发送系统消息，消息类型默认为 notice）
     *
     * @param userList       消息接收用户
     * @param subject        消息标题
     * @param content        消息内容
     * @param pushMessageApi 发送消息API
     */
    public void sendSysMsg(List<String> userList, String subject, String content, IPushMessageApi pushMessageApi) {
        List<String> messageTypeList = new ArrayList<>();
        //系统消息
        messageTypeList.add("sys");
        this.sendMsg(messageTypeList, userList, MSG_TYPE_NOTICE, subject, content, null, null, null, pushMessageApi);
    }

    /**
     * 发送消息
     *
     * @param messageTypeList 消息发送类型
     * @param userList        消息接收用户
     * @param msgType         消息类型
     * @param subject         消息标题
     * @param content         消息内容
     * @param cgddAgentid     cgddAgentid（微信消息使用）
     * @param cgddSecret      cgddSecret （微信消息使用）
     * @param url             微信消息URL（微信消息使用）
     * @param pushMessageApi  发送消息API
     */
    public void sendMsg(List<String> messageTypeList, List<String> userList, String msgType, String subject,
                        String content, String cgddAgentid, String cgddSecret, String url,
                        IPushMessageApi pushMessageApi) {
        logger.info("发送消息开始！===========");
        PushMsgParameter parameter = new PushMsgParameter();
        List<String> channel = new ArrayList<>();
        if (messageTypeList.contains("sys")) {
            // 系统消息
            channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
        }
        if (messageTypeList.contains("smsg")) {
            // 短信消息
//             channel.add(PushMsgParameter.CHANNEL_TYPE_NOTE);
        }
        if (messageTypeList.contains("weChat")) {
            // 系统消息
            channel.add(PushMsgParameter.CHANNEL_TYPE_WEXINEE);
        }
        String[] receivers = userList.toArray(new String[0]);
        parameter.setReceivers(receivers);// 收信人
        parameter.setChannel(channel.toArray(new String[0]));// 消息类型
        parameter.setMsgType(msgType);
        parameter.setSubject(subject);// 标题
        parameter.setContent(content);// 内容
        parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
        parameter.setSendUserId(InvocationInfoProxy.getUserid());

        if (messageTypeList.contains("weChat")) {
            JSONObject weixineeParams = new JSONObject();
            weixineeParams.put("agentid", cgddAgentid);
            weixineeParams.put("secret", cgddSecret);
            weixineeParams.put("msgtype", "textcard");
            weixineeParams.put("title", "消息提醒");
            weixineeParams.put("description", subject);
            weixineeParams.put("url", url);
            weixineeParams.put("btntxt", "点击查看");
            parameter.setWeixineeParams(weixineeParams);
        }
        try {
            logger.info("消息发送参数---------------->{}", JSON.toJSONString(parameter));
            CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
            if (result.isSuccess()) {
                logger.info("消息发送成功---------------->" + result.getMsg());
            }
            else {
                logger.error("消息发送失败---------------->" + result.getMsg());
            }
        }
        catch (Exception e) {
            logger.error("调用消息中心RPC服务异常--------------" + e);
        }
    }

}
